@@ -2,7 +2,9 @@
 #include "ui_mainwindow.h"
 #include <QScrollArea>
 #include <QDebug>
-
+#ifdef Q_WS_MAEMO_5
+    #include <QMaemo5InformationBox>
+#endif
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
     m_ui(new Ui::MainWindow)
@@ -11,12 +13,17 @@ MainWindow::MainWindow(QWidget *parent) :
     #ifdef Q_WS_MAEMO_5
         handler = new MaemoApplicationHandler();
     #else
-        handler = new MaemoApplicationHandler("nokes.nokia.com",8080);
+        handler = new MaemoApplicationHandler();
+        qDebug ("proxy");
     #endif
+
+    connect (handler,SIGNAL (raiseError(QString)),this,SLOT(errorHandler(QString)));
+
     loading = new LoadWidget (m_ui->freshestFrame);
+    loading->setGeometry(98,161,50,50);
     loading->startLoading();
 
-    handler->requestApplications("Maemo5","",1,0,"","hot");
+    handler->requestApplications("Maemo5","",0,1,"","high");
     connect (handler,SIGNAL(applicationListReady(QList<MaemoApplication*>*)),this,SLOT(receivedPromoted(QList<MaemoApplication*>*)));
     //categoryList = new CategoryListWidget (m_ui->mainWidget);
     topWidgets = new QList <SubWindow*>();
@@ -55,7 +62,7 @@ MainWindow::MainWindow(QWidget *parent) :
     for (int i=0;i<buttonGroup->buttons().length();i++) {
         buttonGroup->buttons().at(i)->setEnabled(false);
     }
-
+    m_ui->searchButton->setEnabled(false);
     connect (buttonGroup,SIGNAL(buttonClicked(int)),this,SLOT(openListView(int)));
 
     DEFAULTBC1="Maemo 5";
@@ -70,10 +77,22 @@ MainWindow::~MainWindow()
     delete m_ui;
 }
 
+void MainWindow::errorHandler(QString error) {
+    qDebug () << "start error handling";
+    #ifdef Q_WS_MAEMO_5
+        qDebug () << "show error msg!";
+        QMaemo5InformationBox::information(m_ui->centralwidget,error+"\nPlease try again!\n");
+    #else
+        qDebug () << "dsaf";
+    #endif
+}
+
 void MainWindow::receivedPromoted(QList<MaemoApplication*>* promos) {
+    qDebug () << "reveive Promoted";
     for (int i=0;i<buttonGroup->buttons().length();i++) {
         buttonGroup->buttons().at(i)->setEnabled(true);
     }
+    m_ui->searchButton->setEnabled(true);
     disconnect (handler,SIGNAL(applicationListReady(QList<MaemoApplication*>*)),this,SLOT(receivedPromoted(QList<MaemoApplication*>*)));
     if (promos->length()>0) {
         MaemoApplication *app = promos->takeFirst();
@@ -92,6 +111,16 @@ void MainWindow::receivedPromoted(QList<MaemoApplication*>* promos) {
             feat->setGeometry(0,0,247,40);
             feat->show();
         }
+    } else {
+        loading->stopLoading();
+        delete loading;
+        QLabel *errorLabel = new QLabel (m_ui->freshestFrame);
+        errorLabel->setStyleSheet("color: #999999; font: 16px;font-family: \"NokiaSans\";");
+        errorLabel->setGeometry(5,0,247,372);
+        errorLabel->setWordWrap (true);
+        errorLabel->setText("No preview available.");
+        errorLabel->setAlignment(Qt::AlignCenter);
+        errorLabel->show();
     }
 
 }
@@ -163,22 +192,26 @@ void MainWindow::openListView(int buttonid) {
     if (buttonid!=CATEGORY) {
         ApplicationList *applicationList = new ApplicationList (handler,this);
         QString sortmode="";
+        QString title;
         switch (buttonid) {
         case FRESHEST:
             sortmode = "new";
+            title = "Freshest updates";
             break;
         case DOWNLOAD:
             sortmode = "down";
+            title = "Most downloaded";
             break;
         case RATING:
             sortmode = "high";
+            title = "Best rated";
             break;
         }
         applicationList -> requestApplications (ApplicationList::ALL,"Maemo5","",1,10,"",sortmode);
         applicationList->setGeometry(0,54,800,426);
         connect (applicationList, SIGNAL (layerAdded (QWidget*,QString,QString)),this, SLOT(addWidgetLayer(QWidget*,QString,QString)));
         applicationList->show();
-        addWidgetLayer (applicationList,"Maemo 5","Top 10");
+        addWidgetLayer (applicationList,"Maemo 5",title);
     }
     else {
         CategoryView *view = new CategoryView (handler,this);
