@@ -28,7 +28,7 @@ public slots:
     void removeUpperLayer();
     void addWidgetLayer(QWidget*,QString,QString);
     void setBreadCrumbs (QString,QString,bool setDefault=false);
-
+    void errorHandler (QString);
 
 private slots:
     void openListView (int);
@@ -36,8 +36,6 @@ private slots:
     void receivedPromoted (QList<MaemoApplication*>*);
     void promoPreviewReceived(QPixmap*,QString,QString);
     void receivedPromotedAppDetails(MaemoApplicationDetails*);
-//protected:
-//    virtual void changeEvent(QEvent *e);
 
 private:
     enum buttons {FRESHEST,CATEGORY,DOWNLOAD,RATING};
